import { useEffect, useState } from 'react';
import { useNavigate, useLocation } from 'react-router-dom';
import { openFromOtherPage } from './openFromOtherpAge';

// Funktion, um den Haupttab zu öffnen
export const openTab = (tabId: string, tabClass: string) => {
  console.log((document.getElementById(tabId) as HTMLElement).classList[1])
  console.log(`tabclass is ${tabClass}`)
  const tabs = document.getElementsByClassName(tabClass);
  for (let index = 0; index < tabs.length; index++) {
    (tabs[index] as HTMLElement).style.display = 'none';
    
  }

  const selectedTab = document.getElementById(tabId);
  if (selectedTab) {
    selectedTab.style.display = 'block';
  }
};

// Funktion, um verschachtelte Tabs zu öffnen
export const openNestedTab = (parentTabId: string, childTabId: string, parentClass: string, childClass: string) => {
  openTab(parentTabId, parentClass);

  const nestedTabs = document.querySelectorAll(`#${parentTabId} ${childClass}`);
  nestedTabs.forEach((tab) => {
    (tab as HTMLElement).style.display = 'none';
  });

  const selectedNestedTab = document.getElementById(childTabId);
  if (selectedNestedTab) {
    selectedNestedTab.style.display = 'block';
  }
};

// Funktion, um zu einem bestimmten Bereich (z.B. Collapse) zu scrollen
export const handleScrollToCollapse = (collapseId: string) => {
  const collapseElement = document.getElementById(collapseId);
  if (collapseElement) {
    const elementTop = collapseElement.getBoundingClientRect().top + window.pageYOffset;
    const offset = window.innerHeight / 2 - collapseElement.offsetHeight / 2;
    const scrollPosition = elementTop - offset;

    window.scrollTo({
      top: scrollPosition,
      behavior: 'smooth',
    });
  }
};

// Custom Hook zur zentralen Tab-Navigation
export const useTabNavigation = () => {
  const navigate = useNavigate();
  const location = useLocation();
  const [activeTab, setActiveTab] = useState<string | null>(null);
  const [activeSubTab, setActiveSubTab] = useState<string | null>(null);

  // Tab-Wechsel und URL-Update
  const handleTabChange = (tabId: string, subTabId?: string) => {
    setActiveTab(tabId);
    setActiveSubTab(subTabId || null);

    // URL entsprechend aktualisieren
    let newUrl = `${location.pathname}?tab=${tabId}`;
    if (subTabId) {
      newUrl += `&subTab=${subTabId}`;
    }
    navigate(newUrl, { replace: true });
  };

  useEffect(() => {
    console.log("Use Effect")
    const params = new URLSearchParams(location.search);
    const tabId = params.get('tab');
    const subTabId = params.get('subTab');
    const collapseId = params.get('collapseId');
   
    
    // Öffne Haupt- und ggf. verschachtelten Tab
    if (tabId) {
      let tab = document.getElementById(tabId);
      let tabClass = tab!.className; 
      if (subTabId) {
        let subTab = document.getElementById(subTabId);
        let parentClass = (subTab as HTMLElement).classList[1]; 
        openNestedTab(tabId, subTabId, parentClass, tabClass);
      } else {
        openTab(tabId, tabClass);
      }
    }

    // Scrollen zu einem bestimmten Collapsible-Element
    if (collapseId) {
      handleScrollToCollapse(collapseId);
    }

    // Tab von einer anderen Seite öffnen (falls definiert)
    if (tabId) {
      openFromOtherPage(tabId)({ currentTarget: document.getElementById(tabId)! });
    }

    setActiveTab(tabId);
    setActiveSubTab(subTabId || null);
  }, [location.search]);

  return { activeTab, activeSubTab, handleTabChange };
};


